@@ -6,8 +6,7 @@
 #include <gnome.h>
 #include <gdk/gdkkeysyms.h>
 
-#include <hex-document.h>
-
+#include "hex-document.h"
 #include "gtkhex.h"
 
 #define DISPLAY_BORDER 4
@@ -21,8 +20,6 @@
 
 #define is_printable(c) (((c>=0x20) && (c<=0xFF))?1:0)
 
-#define DEBUG
-
 typedef void (*DataChangedSignal)(GtkObject *, gpointer, gpointer);
 
 enum {
@@ -274,7 +271,6 @@ static void hide_cursor(GtkHex *gh) {
 /*
  * renders a byte at offset pos in both displays
  */ 
-
 static void render_byte(GtkHex *gh, gint pos) {
   gint cx, cy;
   gchar buf[2];
@@ -299,10 +295,6 @@ static void render_byte(GtkHex *gh, gint pos) {
 		     cx, cy, 2*gh->char_width, gh->char_height);
   gdk_gc_set_foreground(gh->xdisp_gc, &GTK_WIDGET(gh)->style->text[GTK_STATE_NORMAL]);
 
-  /*  gdk_window_clear_area (gh->xdisp->window,
-      cx, cy,
-      2*gh->char_width, gh->char_height); */
-
   gdk_draw_text(gh->xdisp->window, gh->disp_font, gh->xdisp_gc,
 		cx, cy + gh->disp_font->ascent, buf, 2);
 
@@ -313,10 +305,6 @@ static void render_byte(GtkHex *gh, gint pos) {
 		     cx, cy, gh->char_width, gh->char_height);
   gdk_gc_set_foreground(gh->adisp_gc, &GTK_WIDGET(gh)->style->text[GTK_STATE_NORMAL]);
 
-  /*  gdk_window_clear_area (gh->adisp->window,
-      cx, cy,
-      gh->char_width, gh->char_height); */
-
   gdk_draw_text(gh->adisp->window, gh->disp_font, gh->adisp_gc,
 		cx, cy + gh->disp_font->ascent, &gh->document->buffer[pos], 1);
 }
@@ -343,16 +331,13 @@ static void render_hex_lines(GtkHex *gh, gint imin, gint imax) {
 
   cursor_line = gh->cursor_pos / gh->cpl - gh->top_line;
 
-  imax = MIN(imax, gh->vis_lines);
-
-  /* gdk_window_clear_area (w->window, 0, imin*gh->char_height,
-                            w->allocation.width,
-			    (imax - imin + 1)*gh->char_height); */
-
   gdk_gc_set_foreground(gh->xdisp_gc, &GTK_WIDGET(gh)->style->base[GTK_STATE_NORMAL]);
   gdk_draw_rectangle(w->window, gh->xdisp_gc, TRUE,
 		     0, imin*gh->char_height, w->allocation.width,
 		     (imax - imin + 1)*gh->char_height);
+
+  imax = MIN(imax, gh->vis_lines);
+
   gdk_gc_set_foreground(gh->xdisp_gc, &GTK_WIDGET(gh)->style->text[GTK_STATE_NORMAL]);
 
   frm_len = format_xblock(gh, gh->disp_buffer, (gh->top_line+imin)*gh->cpl,
@@ -387,15 +372,13 @@ static void render_ascii_lines(GtkHex *gh, gint imin, gint imax) {
 
   cursor_line = gh->cursor_pos / gh->cpl - gh->top_line;
 
-  imax = MIN(imax, gh->vis_lines);
-
-  /* gdk_window_clear_area (w->window, 0, imin*gh->char_height, w->allocation.width,
-			 (imax - imin + 1)*gh->char_height); */
-
   gdk_gc_set_foreground(gh->xdisp_gc, &GTK_WIDGET(gh)->style->base[GTK_STATE_NORMAL]);
   gdk_draw_rectangle(w->window, gh->xdisp_gc, TRUE,
 		     0, imin*gh->char_height, w->allocation.width,
 		     (imax - imin + 1)*gh->char_height);
+
+  imax = MIN(imax, gh->vis_lines);
+
   gdk_gc_set_foreground(gh->xdisp_gc, &GTK_WIDGET(gh)->style->text[GTK_STATE_NORMAL]);
 
   frm_len = format_ablock(gh, gh->disp_buffer, (gh->top_line+imin)*gh->cpl,
@@ -422,8 +405,6 @@ static void hex_expose(GtkWidget *w, GdkEventExpose *event, GtkHex *gh) {
   gint imin, imax;
 
   imin = (event->area.y) / gh->char_height;
-  if(imin > gh->vis_lines)
-    return;
   imax = (event->area.y + event->area.height) / gh->char_height;
   if((event->area.y + event->area.height) % gh->char_height)
     imax++;
@@ -435,8 +416,6 @@ static void ascii_expose(GtkWidget *w, GdkEventExpose *event, GtkHex *gh) {
   gint imin, imax;
 
   imin = (event->area.y) / gh->char_height;
-  if(imin > gh->vis_lines)
-    return;
   imax = (event->area.y + event->area.height) / gh->char_height;
   if((event->area.y + event->area.height) % gh->char_height)
     imax++;
@@ -451,6 +430,10 @@ static void draw_shadow(GtkWidget *widget, GdkEventExpose *event) {
   GtkHex *gh = GTK_HEX(widget);
   gint border = GTK_CONTAINER(widget)->border_width;
 
+  gdk_window_set_back_pixmap (widget->window, NULL, TRUE);
+  gdk_window_clear_area (widget->window, event->area.x, event->area.y,
+			 event->area.width, event->area.height);
+
   gtk_draw_shadow(widget->style, widget->window,
 		  GTK_STATE_NORMAL, GTK_SHADOW_IN,
 		  border, border, gh->xdisp_width + 2*SHADOW_WIDTH,
@@ -552,9 +535,6 @@ static void resize_displays(GtkWidget *w, GtkAllocation *alloc) {
   my_alloc.height = alloc->height - 2*GTK_CONTAINER(gh)->border_width - 2*SHADOW_WIDTH;
   my_alloc.width = gh->xdisp_width;
   gtk_signal_emit_by_name(GTK_OBJECT(gh->xdisp), "size_allocate", &my_alloc);
-  /*  my_alloc.x += my_alloc.width + DISPLAY_SPACING;
-      my_alloc.width = gh->separator->allocation.width;
-      gtk_signal_emit_by_name(GTK_OBJECT(gh->separator), "size_allocate", &my_alloc); */
   my_alloc.x += my_alloc.width + 2*SHADOW_WIDTH + DISPLAY_SPACING;
   my_alloc.width = gh->adisp_width;
   gtk_signal_emit_by_name(GTK_OBJECT(gh->adisp), "size_allocate", &my_alloc);
@@ -732,10 +712,6 @@ static void gtk_hex_real_data_changed(GtkHex *gh, gpointer data) {
 static void gtk_hex_destroy(GtkObject *o) {
   GtkHex *gh = GTK_HEX(o);
 
-#ifdef DEBUG
-  printf("GtkHex: destroying!\n");
-#endif
-
   if(gh->disp_buffer)
     free(gh->disp_buffer);
 }
@@ -855,6 +831,8 @@ static void gtk_hex_class_init(GtkHexClass *class) {
 }
 
 static void gtk_hex_init(GtkHex *gh) {
+  GtkWidget *widget = GTK_WIDGET(gh);
+
   gh->disp_buffer = NULL;
   gh->document = NULL;
 
@@ -878,9 +856,11 @@ static void gtk_hex_init(GtkHex *gh) {
   gtk_container_border_width(GTK_CONTAINER(gh), DISPLAY_BORDER);
   gtk_signal_connect(GTK_OBJECT(gh), "expose_event",
 		     GTK_SIGNAL_FUNC(draw_shadow), NULL);
+  gtk_signal_connect(GTK_OBJECT(gh), "draw",
+		     GTK_SIGNAL_FUNC(draw_shadow), NULL);
   gtk_signal_connect(GTK_OBJECT(gh), "size_allocate",
 		     GTK_SIGNAL_FUNC(resize_displays), NULL);
-
+  
   gh->adj = GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 0.0, 0.0, 0.0, 0.0));
 
   gh->xdisp = gtk_drawing_area_new();
@@ -1005,10 +985,6 @@ guchar gtk_hex_get_byte(GtkHex *gh, guint offset) {
 void gtk_hex_set_group_type(GtkHex *gh, guint gt) {
   GtkAllocation alloc;
 
-#ifdef DEBUG
-  printf("GtkHex: setting group type!\n");
-#endif
-
   memcpy(&alloc, &(GTK_WIDGET(gh)->allocation), sizeof(GtkAllocation));
 
   gh->group_type = gt;
