@@ -9,13 +9,9 @@
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
 
-#include <libgnome/libgnome.h>
+#include <gnome.h>
 
-#include <libgnomeui/libgnomeui.h>
-
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+BEGIN_GNOME_DECLS
 
 #define HEX_DOCUMENT(obj)          GTK_CHECK_CAST (obj, hex_document_get_type (), HexDocument)
 #define HEX_DOCUMENT_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, hex_document_get_type (), HexDocumentClass)
@@ -61,5 +57,7 @@ void hex_document_changed(HexDocument *doc, gpointer change_data);
 gint find_string_forward(HexDocument *doc, guint start, guchar *what, gint len, guint *found);
 gint find_string_backward(HexDocument *doc, guint start, guchar *what, gint len, guint *found);
 
+END_GNOME_DECLS
+
 #endif /* __HEX_DOCUMENT_H__ */
 
