@@ -38,8 +38,6 @@ int main(int argc, char **argv) {
   bindtextdomain (PACKAGE, GNOMELOCALEDIR);
   textdomain(PACKAGE);
 
-  printf("starting ghex\n");
-
   gnome_init("ghex", &parser, argc, argv, 0, NULL);
 
   client = gnome_master_client();
@@ -60,6 +58,7 @@ int main(int argc, char **argv) {
     /* connect signals */
     gtk_signal_connect(GTK_OBJECT(mdi), "remove_child", GTK_SIGNAL_FUNC(remove_doc_cb), NULL);
     gtk_signal_connect(GTK_OBJECT(mdi), "destroy", GTK_SIGNAL_FUNC(cleanup_cb), NULL);
+    gtk_signal_connect(GTK_OBJECT(mdi), "view_changed", GTK_SIGNAL_FUNC(view_changed_cb), NULL);
 
     /* load preferences */
     load_configuration();
