@@ -12,19 +12,10 @@
 #include "gnome-month-item.h"
 
 
-/* These are indices into the items array of a GnomeMonthItem structure */
-enum {
-	ITEM_HEAD_GROUP = 0,	/* 7 groups */
-	ITEM_HEAD_BOX   = 7,	/* 7 boxes */
-	ITEM_HEAD_LABEL = 14,	/* 7 labels */
-	ITEM_DAY_GROUP  = 21,	/* 42 groups */
-	ITEM_DAY_BOX    = 63,	/* 42 boxes */
-	ITEM_DAY_LABEL  = 105	/* 42 labels */
-};
 
 
 /* Number of days in a month, for normal and leap years */
-static int days_in_month[2][12] = {
+static const int days_in_month[2][12] = {
 	{ 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 },
 	{ 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 }
 };
@@ -32,7 +23,7 @@ static int days_in_month[2][12] = {
 /* The weird month of September 1752, where 3 Sep through 13 Sep were eliminated due to the
  * Gregorian reformation.
  */
-static int sept_1752[42] = {
+static const int sept_1752[42] = {
 	 0,  0,  1,  2, 14, 15, 16,
 	17, 18, 19, 20, 21, 22, 23,
 	24, 25, 26, 27, 28, 29, 30,
@@ -64,7 +55,19 @@ enum {
 	ARG_HEADING_HEIGHT,
 	ARG_HEADING_ANCHOR,
 	ARG_DAY_ANCHOR,
-	ARG_START_ON_MONDAY
+	ARG_START_ON_MONDAY,
+	ARG_HEAD_FONT,
+	ARG_HEAD_FONT_GDK,
+	ARG_DAY_FONT,
+	ARG_DAY_FONT_GDK,
+	ARG_HEAD_COLOR,
+	ARG_HEAD_COLOR_GDK,
+	ARG_OUTLINE_COLOR,
+	ARG_OUTLINE_COLOR_GDK,
+	ARG_DAY_BOX_COLOR,
+	ARG_DAY_BOX_COLOR_GDK,
+	ARG_DAY_COLOR,
+	ARG_DAY_COLOR_GDK
 };
 
 
@@ -124,13 +127,25 @@ gnome_month_item_class_init (GnomeMonthItemClass *class)
 	gtk_object_add_arg_type ("GnomeMonthItem::width", GTK_TYPE_DOUBLE, GTK_ARG_READWRITE, ARG_WIDTH);
 	gtk_object_add_arg_type ("GnomeMonthItem::height", GTK_TYPE_DOUBLE, GTK_ARG_READWRITE, ARG_HEIGHT);
 	gtk_object_add_arg_type ("GnomeMonthItem::anchor", GTK_TYPE_ANCHOR_TYPE, GTK_ARG_READWRITE, ARG_ANCHOR);
-	gtk_object_add_arg_type ("GnomeMonthItem::head_padding", GTK_TYPE_DOUBLE, GTK_ARG_READWRITE, ARG_HEAD_PADDING);
+	gtk_object_add_arg_type ("GnomeMonthItem::heading_padding", GTK_TYPE_DOUBLE, GTK_ARG_READWRITE, ARG_HEAD_PADDING);
 	gtk_object_add_arg_type ("GnomeMonthItem::day_padding", GTK_TYPE_DOUBLE, GTK_ARG_READWRITE, ARG_DAY_PADDING);
-	gtk_object_add_arg_type ("GnomeMonthItem::day_names", GTK_TYPE_POINTER, GTK_ARG_READABLE, ARG_DAY_NAMES);
+	gtk_object_add_arg_type ("GnomeMonthItem::day_names", GTK_TYPE_POINTER, GTK_ARG_WRITABLE, ARG_DAY_NAMES);
 	gtk_object_add_arg_type ("GnomeMonthItem::heading_height", GTK_TYPE_DOUBLE, GTK_ARG_READWRITE, ARG_HEADING_HEIGHT);
 	gtk_object_add_arg_type ("GnomeMonthItem::heading_anchor", GTK_TYPE_ANCHOR_TYPE, GTK_ARG_READWRITE, ARG_HEADING_ANCHOR);
 	gtk_object_add_arg_type ("GnomeMonthItem::day_anchor", GTK_TYPE_ANCHOR_TYPE, GTK_ARG_READWRITE, ARG_DAY_ANCHOR);
 	gtk_object_add_arg_type ("GnomeMonthItem::start_on_monday", GTK_TYPE_BOOL, GTK_ARG_READWRITE, ARG_START_ON_MONDAY);
+	gtk_object_add_arg_type ("GnomeMonthItem::heading_font", GTK_TYPE_STRING, GTK_ARG_WRITABLE, ARG_HEAD_FONT);
+	gtk_object_add_arg_type ("GnomeMonthItem::heading_font_gdk", GTK_TYPE_GDK_FONT, GTK_ARG_READWRITE, ARG_HEAD_FONT_GDK);
+	gtk_object_add_arg_type ("GnomeMonthItem::day_font", GTK_TYPE_STRING, GTK_ARG_WRITABLE, ARG_DAY_FONT);
+	gtk_object_add_arg_type ("GnomeMonthItem::day_font_gdk", GTK_TYPE_GDK_FONT, GTK_ARG_READWRITE, ARG_DAY_FONT_GDK);
+	gtk_object_add_arg_type ("GnomeMonthItem::heading_color", GTK_TYPE_STRING, GTK_ARG_WRITABLE, ARG_HEAD_COLOR);
+	gtk_object_add_arg_type ("GnomeMonthItem::heading_color_gdk", GTK_TYPE_GDK_COLOR, GTK_ARG_READWRITE, ARG_HEAD_COLOR_GDK);
+	gtk_object_add_arg_type ("GnomeMonthItem::outline_color", GTK_TYPE_STRING, GTK_ARG_WRITABLE, ARG_OUTLINE_COLOR);
+	gtk_object_add_arg_type ("GnomeMonthItem::outline_color_gdk", GTK_TYPE_GDK_COLOR, GTK_ARG_READWRITE, ARG_OUTLINE_COLOR_GDK);
+	gtk_object_add_arg_type ("GnomeMonthItem::day_box_color", GTK_TYPE_STRING, GTK_ARG_WRITABLE, ARG_DAY_BOX_COLOR);
+	gtk_object_add_arg_type ("GnomeMonthItem::day_box_color_gdk", GTK_TYPE_GDK_COLOR, GTK_ARG_READWRITE, ARG_DAY_BOX_COLOR_GDK);
+	gtk_object_add_arg_type ("GnomeMonthItem::day_color", GTK_TYPE_STRING, GTK_ARG_WRITABLE, ARG_DAY_COLOR);
+	gtk_object_add_arg_type ("GnomeMonthItem::day_color_gdk", GTK_TYPE_GDK_COLOR, GTK_ARG_READWRITE, ARG_DAY_COLOR_GDK);
 
 	object_class->destroy = gnome_month_item_destroy;
 	object_class->set_arg = gnome_month_item_set_arg;
@@ -196,13 +211,13 @@ reshape_headings (GnomeMonthItem *mitem)
 
 	for (i = 0; i < 7; i++) {
 		/* Group */
-		gnome_canvas_item_set (mitem->items[ITEM_HEAD_GROUP + i],
+		gnome_canvas_item_set (mitem->items[GNOME_MONTH_ITEM_HEAD_GROUP + i],
 				       "x", width * i,
 				       "y", 0.0,
 				       NULL);
 
 		/* Box */
-		gnome_canvas_item_set (mitem->items[ITEM_HEAD_BOX + i],
+		gnome_canvas_item_set (mitem->items[GNOME_MONTH_ITEM_HEAD_BOX + i],
 				       "x1", 0.0,
 				       "y1", 0.0,
 				       "x2", width,
@@ -217,7 +232,7 @@ reshape_headings (GnomeMonthItem *mitem)
 				  mitem->head_height - mitem->head_padding,
 				  &x, &y);
 
-		gnome_canvas_item_set (mitem->items[ITEM_HEAD_LABEL + i],
+		gnome_canvas_item_set (mitem->items[GNOME_MONTH_ITEM_HEAD_LABEL + i],
 				       "x", x,
 				       "y", y,
 				       "anchor", mitem->head_anchor,
@@ -242,13 +257,13 @@ reshape_days (GnomeMonthItem *mitem)
 	for (row = 0; row < 6; row++)
 		for (col = 0; col < 7; col++) {
 			/* Group */
-			gnome_canvas_item_set (mitem->items[ITEM_DAY_GROUP + i],
+			gnome_canvas_item_set (mitem->items[GNOME_MONTH_ITEM_DAY_GROUP + i],
 					       "x", width * col,
 					       "y", mitem->head_height + height * row,
 					       NULL);
 
 			/* Box */
-			gnome_canvas_item_set (mitem->items[ITEM_DAY_BOX + i],
+			gnome_canvas_item_set (mitem->items[GNOME_MONTH_ITEM_DAY_BOX + i],
 					       "x1", 0.0,
 					       "y1", 0.0,
 					       "x2", width,
@@ -263,7 +278,7 @@ reshape_days (GnomeMonthItem *mitem)
 					  height - mitem->day_padding,
 					  &x, &y);
 
-			gnome_canvas_item_set (mitem->items[ITEM_DAY_LABEL + i],
+			gnome_canvas_item_set (mitem->items[GNOME_MONTH_ITEM_DAY_LABEL + i],
 					       "x", x,
 					       "y", y,
 					       "anchor", mitem->day_anchor,
@@ -283,6 +298,40 @@ reshape (GnomeMonthItem *mitem)
 	reshape_days (mitem);
 }
 
+/* Sets the font for all the day headings */
+static void
+set_head_font (GnomeMonthItem *mitem)
+{
+	int i;
+
+	for (i = 0; i < 7; i++)
+		gnome_canvas_item_set (mitem->items[GNOME_MONTH_ITEM_HEAD_LABEL + i],
+				       "font_gdk", mitem->head_font,
+				       NULL);
+}
+
+/* Sets the color for all the headings */
+static void
+set_head_color (GnomeMonthItem *mitem)
+{
+	int i;
+	GdkColor outline;
+	GdkColor head;
+
+	outline.pixel = mitem->outline_pixel;
+	head.pixel = mitem->head_pixel;
+
+	for (i = 0; i < 7; i++) {
+		gnome_canvas_item_set (mitem->items[GNOME_MONTH_ITEM_HEAD_BOX + i],
+				       "fill_color_gdk", &outline,
+				       NULL);
+
+		gnome_canvas_item_set (mitem->items[GNOME_MONTH_ITEM_HEAD_LABEL + i],
+				       "fill_color_gdk", &head,
+				       NULL);
+	}
+}
+
 /* Creates the items for the day name headings */
 static void
 create_headings (GnomeMonthItem *mitem)
@@ -293,26 +342,26 @@ create_headings (GnomeMonthItem *mitem)
 
 	for (i = 0; i < 7; i++) {
 		/* Group */
-		mitem->items[ITEM_HEAD_GROUP + i] =
+		mitem->items[GNOME_MONTH_ITEM_HEAD_GROUP + i] =
 			gnome_canvas_item_new (GNOME_CANVAS_GROUP (mitem),
 					       gnome_canvas_group_get_type (),
 					       NULL);
 
 		/* Box */
-		mitem->items[ITEM_HEAD_BOX + i] =
-			gnome_canvas_item_new (GNOME_CANVAS_GROUP (mitem->items[ITEM_HEAD_GROUP + i]),
+		mitem->items[GNOME_MONTH_ITEM_HEAD_BOX + i] =
+			gnome_canvas_item_new (GNOME_CANVAS_GROUP (mitem->items[GNOME_MONTH_ITEM_HEAD_GROUP + i]),
 					       gnome_canvas_rect_get_type (),
-					       "fill_color", "black",
 					       NULL);
 
 		/* Label */
-		mitem->items[ITEM_HEAD_LABEL + i] =
-			gnome_canvas_item_new (GNOME_CANVAS_GROUP (mitem->items[ITEM_HEAD_GROUP + i]),
+		mitem->items[GNOME_MONTH_ITEM_HEAD_LABEL + i] =
+			gnome_canvas_item_new (GNOME_CANVAS_GROUP (mitem->items[GNOME_MONTH_ITEM_HEAD_GROUP + i]),
 					       gnome_canvas_text_get_type (),
-					       "fill_color", "white",
-					       "font", "-adobe-helvetica-medium-r-normal--10-*-72-72-p-*-iso8859-1",
 					       NULL);
 	}
+
+	set_head_font (mitem);
+	set_head_color (mitem);
 }
 
 /* Returns the number of leap years since year 1 up to (but not including) the specified year */
@@ -372,7 +421,7 @@ day_in_week (int day, int month, int year)
  * returned in the start and end arguments.
  */
 static void
-build_month (int month, int year, int *days, int *start, int *end)
+build_month (int month, int year, int start_on_monday, int *days, int *start, int *end)
 {
 	int i;
 	int d_month, d_week;
@@ -397,6 +446,9 @@ build_month (int month, int year, int *days, int *start, int *end)
 	d_month = days_in_month[is_leap_year (year)][month];
 	d_week = day_in_week (1, month, year);
 
+	if (start_on_monday)
+		d_week = (d_week + 6) % 7;
+
 	for (i = 0; i < d_month; i++)
 		days[d_week + i] = i + 1;
 
@@ -411,30 +463,24 @@ build_month (int month, int year, int *days, int *start, int *end)
 static void
 set_days (GnomeMonthItem *mitem)
 {
-	int i, ofs;
-	int days[42];
+	int i;
 	int start, end;
 	char buf[100];
 
-	build_month (mitem->month, mitem->year, days, &start, &end);
-
-	if (mitem->start_on_monday)
-		ofs = (start + 6) % 7;
-	else
-		ofs = start;
+	build_month (mitem->month, mitem->year, mitem->start_on_monday, mitem->day_numbers, &start, &end);
 
 	/* Clear days before start of month */
 
-	for (i = 0; i < ofs; i++)
-		gnome_canvas_item_set (mitem->items[ITEM_DAY_LABEL + i],
+	for (i = 0; i < start; i++)
+		gnome_canvas_item_set (mitem->items[GNOME_MONTH_ITEM_DAY_LABEL + i],
 				       "text", NULL,
 				       NULL);
 
 	/* Set days of month */
 
 	for (; start <= end; start++, i++) {
-		sprintf (buf, "%d", days[start]);
-		gnome_canvas_item_set (mitem->items[ITEM_DAY_LABEL + i],
+		sprintf (buf, "%d", mitem->day_numbers[start]);
+		gnome_canvas_item_set (mitem->items[GNOME_MONTH_ITEM_DAY_LABEL + i],
 				       "text", buf,
 				       NULL);
 	}
@@ -442,47 +488,78 @@ set_days (GnomeMonthItem *mitem)
 	/* Clear days after end of month */
 
 	for (; i < 42; i++)
-		gnome_canvas_item_set (mitem->items[ITEM_DAY_LABEL + i],
+		gnome_canvas_item_set (mitem->items[GNOME_MONTH_ITEM_DAY_LABEL + i],
 				       "text", NULL,
 				       NULL);
 }
 
+/* Sets the font for all the day numbers */
+static void
+set_day_font (GnomeMonthItem *mitem)
+{
+	int i;
+
+	for (i = 0; i < 42; i++)
+		gnome_canvas_item_set (mitem->items[GNOME_MONTH_ITEM_DAY_LABEL + i],
+				       "font_gdk", mitem->day_font,
+				       NULL);
+}
+
+/* Sets the color for all the day items */
+static void
+set_day_color (GnomeMonthItem *mitem)
+{
+	int i;
+	GdkColor outline;
+	GdkColor day_box;
+	GdkColor day;
+
+	outline.pixel = mitem->outline_pixel;
+	day_box.pixel = mitem->day_box_pixel;
+	day.pixel = mitem->day_pixel;
+
+	for (i = 0; i < 42; i++) {
+		gnome_canvas_item_set (mitem->items[GNOME_MONTH_ITEM_DAY_BOX + i],
+				       "outline_color_gdk", &outline,
+				       "fill_color_gdk", &day_box,
+				       NULL);
+
+		gnome_canvas_item_set (mitem->items[GNOME_MONTH_ITEM_DAY_LABEL + i],
+				       "fill_color_gdk", &day,
+				       NULL);
+	}
+}
+
 /* Creates the items for the days */
 static void
 create_days (GnomeMonthItem *mitem)
 {
 	int i;
-	char buf[100];
-	GdkColor *c;
 
 	/* Just create the items; they will be positioned and configured by a call to reshape() */
 
 	for (i = 0; i < 42; i++) {
 		/* Group */
-		mitem->items[ITEM_DAY_GROUP + i] =
+		mitem->items[GNOME_MONTH_ITEM_DAY_GROUP + i] =
 			gnome_canvas_item_new (GNOME_CANVAS_GROUP (mitem),
 					       gnome_canvas_group_get_type (),
 					       NULL);
 
 		/* Box */
-		c = &GTK_WIDGET (GNOME_CANVAS_ITEM (mitem)->canvas)->style->bg[GTK_STATE_NORMAL];
-		sprintf (buf, "#%04x%04x%04x", c->red, c->green, c->blue);
-		mitem->items[ITEM_DAY_BOX + i] =
-			gnome_canvas_item_new (GNOME_CANVAS_GROUP (mitem->items[ITEM_DAY_GROUP + i]),
+		mitem->items[GNOME_MONTH_ITEM_DAY_BOX + i] =
+			gnome_canvas_item_new (GNOME_CANVAS_GROUP (mitem->items[GNOME_MONTH_ITEM_DAY_GROUP + i]),
 					       gnome_canvas_rect_get_type (),
-					       "outline_color", "black",
-					       "fill_color", buf,
 					       NULL);
 
 		/* Label */
-		mitem->items[ITEM_DAY_LABEL + i] =
-			gnome_canvas_item_new (GNOME_CANVAS_GROUP (mitem->items[ITEM_DAY_GROUP + i]),
+		mitem->items[GNOME_MONTH_ITEM_DAY_LABEL + i] =
+			gnome_canvas_item_new (GNOME_CANVAS_GROUP (mitem->items[GNOME_MONTH_ITEM_DAY_GROUP + i]),
 					       gnome_canvas_text_get_type (),
-					       "fill_color", "black",
-					       "font", "-adobe-helvetica-medium-r-normal--10-*-72-72-p-*-iso8859-1",
 					       NULL);
 	}
 
+	set_day_font (mitem);
+	set_day_color (mitem);
 	set_days (mitem);
 }
 
@@ -493,7 +570,7 @@ set_day_names (GnomeMonthItem *mitem)
 	int i;
 
 	for (i = 0; i < 7; i++)
-		gnome_canvas_item_set (mitem->items[ITEM_HEAD_LABEL + i],
+		gnome_canvas_item_set (mitem->items[GNOME_MONTH_ITEM_HEAD_LABEL + i],
 				       "text", mitem->day_names[mitem->start_on_monday ? ((i + 1) % 7) : i],
 				       NULL);
 }
@@ -502,30 +579,20 @@ set_day_names (GnomeMonthItem *mitem)
 static void
 create_items (GnomeMonthItem *mitem)
 {
-	/*  7 heading groups
-	 *  7 heading boxes
-	 *  7 heading labels
-	 * 42 day groups
-	 * 42 day boxes
-	 * 42 day labels
-	 * ------------------
-	 * 147 items total
-	 */
-
-	mitem->items = g_new (GnomeCanvasItem *, 147);
+	mitem->items = g_new (GnomeCanvasItem *, GNOME_MONTH_ITEM_LAST);
 
 	create_headings (mitem);
 	create_days (mitem);
 
 	/* Initialize by default to three-letter day names */
 
-	mitem->day_names[0] = _("Sun");
-	mitem->day_names[1] = _("Mon");
-	mitem->day_names[2] = _("Tue");
-	mitem->day_names[3] = _("Wed");
-	mitem->day_names[4] = _("Thu");
-	mitem->day_names[5] = _("Fri");
-	mitem->day_names[6] = _("Sat");
+	mitem->day_names[0] = g_strdup (_("Sun"));
+	mitem->day_names[1] = g_strdup (_("Mon"));
+	mitem->day_names[2] = g_strdup (_("Tue"));
+	mitem->day_names[3] = g_strdup (_("Wed"));
+	mitem->day_names[4] = g_strdup (_("Thu"));
+	mitem->day_names[5] = g_strdup (_("Fri"));
+	mitem->day_names[6] = g_strdup (_("Sat"));
 	
 	set_day_names (mitem);
 	reshape (mitem);
@@ -555,6 +622,20 @@ gnome_month_item_init (GnomeMonthItem *mitem)
 	mitem->head_height = 14.0;
 	mitem->head_anchor = GTK_ANCHOR_CENTER;
 	mitem->day_anchor = GTK_ANCHOR_CENTER;
+
+	/* Load the default fonts */
+
+	mitem->head_font = gdk_font_load ("-*-helvetica-medium-r-normal--10-*-*-*-p-*-iso8859-1");
+	if (!mitem->head_font) {
+		mitem->head_font = gdk_font_load ("fixed");
+		g_assert (mitem->head_font != NULL);
+	}
+
+	mitem->day_font = gdk_font_load ("-adobe-helvetica-medium-r-normal--10-*-72-72-p-*-iso8859-1");
+	if (!mitem->day_font) {
+		mitem->day_font = gdk_font_load ("fixed");
+		g_assert (mitem->day_font != NULL);
+	}
 }
 
 GnomeCanvasItem *
@@ -577,9 +658,19 @@ gnome_month_item_new (GnomeCanvasGroup *parent)
 void
 gnome_month_item_construct (GnomeMonthItem *mitem)
 {
+	GdkColor color;
+
 	g_return_if_fail (mitem != NULL);
 	g_return_if_fail (GNOME_IS_MONTH_ITEM (mitem));
 
+	gnome_canvas_get_color (GNOME_CANVAS_ITEM (mitem)->canvas, "#d6d6d6d6d6d6", &color);
+	mitem->head_pixel = color.pixel;
+	mitem->day_box_pixel = color.pixel;
+
+	gnome_canvas_get_color (GNOME_CANVAS_ITEM (mitem)->canvas, "black", &color);
+	mitem->outline_pixel = color.pixel;
+	mitem->day_pixel = color.pixel;
+
 	create_items (mitem);
 }
 
@@ -666,10 +757,28 @@ reanchor (GnomeMonthItem *mitem)
 			       NULL);
 }
 
+/* Sets the color of the specified pixel value to that of the specified argument, which must be in
+ * GdkColor format if format is TRUE, otherwise it must be in string format.
+ */
 static void
-recalc_month (GnomeMonthItem *mitem)
+set_color_arg (GnomeMonthItem *mitem, gulong *pixel, GtkArg *arg, int gdk_format, int set_head, int set_day)
 {
-	/* FIXME */
+	GdkColor color;
+
+	if (gdk_format)
+		*pixel = ((GdkColor *) GTK_VALUE_BOXED (*arg))->pixel;
+	else {
+		if (gnome_canvas_get_color (GNOME_CANVAS_ITEM (mitem)->canvas, GTK_VALUE_STRING (*arg), &color))
+			*pixel = color.pixel;
+		else
+			*pixel = 0;
+	}
+
+	if (set_head)
+		set_head_color (mitem);
+
+	if (set_day)
+		set_day_color (mitem);
 }
 
 static void
@@ -684,12 +793,12 @@ gnome_month_item_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 	switch (arg_id) {
 	case ARG_YEAR:
 		mitem->year = GTK_VALUE_UINT (*arg);
-		recalc_month (mitem);
+		set_days (mitem);
 		break;
 
 	case ARG_MONTH:
 		mitem->month = GTK_VALUE_UINT (*arg);
-		recalc_month (mitem);
+		set_days (mitem);
 		break;
 
 	case ARG_X:
@@ -770,11 +879,97 @@ gnome_month_item_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 		set_days (mitem);
 		break;
 
+	case ARG_HEAD_FONT:
+		gdk_font_unref (mitem->head_font);
+
+		mitem->head_font = gdk_font_load (GTK_VALUE_STRING (*arg));
+		if (!mitem->head_font) {
+			mitem->head_font = gdk_font_load ("fixed");
+			g_assert (mitem->head_font != NULL);
+		}
+
+		set_head_font (mitem);
+		break;
+
+	case ARG_HEAD_FONT_GDK:
+		gdk_font_unref (mitem->head_font);
+
+		mitem->head_font = GTK_VALUE_BOXED (*arg);
+		gdk_font_ref (mitem->head_font);
+		set_head_font (mitem);
+		break;
+
+	case ARG_DAY_FONT:
+		gdk_font_unref (mitem->day_font);
+
+		mitem->day_font = gdk_font_load (GTK_VALUE_STRING (*arg));
+		if (!mitem->day_font) {
+			mitem->day_font = gdk_font_load ("fixed");
+			g_assert (mitem->day_font != NULL);
+		}
+
+		set_day_font (mitem);
+		break;
+
+	case ARG_DAY_FONT_GDK:
+		gdk_font_unref (mitem->day_font);
+
+		mitem->day_font = GTK_VALUE_BOXED (*arg);
+		gdk_font_ref (mitem->day_font);
+		set_day_font (mitem);
+		break;
+
+	case ARG_HEAD_COLOR:
+		set_color_arg (mitem, &mitem->head_pixel, arg, FALSE, TRUE, FALSE);
+		break;
+
+	case ARG_HEAD_COLOR_GDK:
+		set_color_arg (mitem, &mitem->head_pixel, arg, TRUE, TRUE, FALSE);
+		break;
+
+	case ARG_OUTLINE_COLOR:
+		set_color_arg (mitem, &mitem->outline_pixel, arg, FALSE, TRUE, TRUE);
+		break;
+
+	case ARG_OUTLINE_COLOR_GDK:
+		set_color_arg (mitem, &mitem->outline_pixel, arg, TRUE, TRUE, TRUE);
+		break;
+
+	case ARG_DAY_BOX_COLOR:
+		set_color_arg (mitem, &mitem->day_box_pixel, arg, FALSE, FALSE, TRUE);
+		break;
+
+	case ARG_DAY_BOX_COLOR_GDK:
+		set_color_arg (mitem, &mitem->day_box_pixel, arg, TRUE, FALSE, TRUE);
+		break;
+
+	case ARG_DAY_COLOR:
+		set_color_arg (mitem, &mitem->day_pixel, arg, FALSE, FALSE, TRUE);
+		break;
+
+	case ARG_DAY_COLOR_GDK:
+		set_color_arg (mitem, &mitem->day_pixel, arg, TRUE, FALSE, TRUE);
+		break;
+
 	default:
 		break;
 	}
 }
 
+/* Allocates a GdkColor structure filled with the specified pixel, and puts it into the specified
+ * arg for returning it in the get_arg method.
+ */
+static void
+get_color_arg (GnomeMonthItem *mitem, gulong pixel, GtkArg *arg)
+{
+	GdkColor *color;
+
+	color = g_new (GdkColor, 1);
+	color->pixel = pixel;
+	gdk_color_context_query_color (GNOME_CANVAS_ITEM (mitem)->canvas->cc, color);
+	GTK_VALUE_BOXED (*arg) = color;
+}
+
 static void
 gnome_month_item_get_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 {
@@ -835,8 +1030,96 @@ gnome_month_item_get_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 		GTK_VALUE_BOOL (*arg) = mitem->start_on_monday;
 		break;
 
+	case ARG_HEAD_FONT_GDK:
+		GTK_VALUE_BOXED (*arg) = mitem->head_font;
+		break;
+
+	case ARG_DAY_FONT_GDK:
+		GTK_VALUE_BOXED (*arg) = mitem->day_font;
+		break;
+
+	case ARG_HEAD_COLOR_GDK:
+		get_color_arg (mitem, mitem->head_pixel, arg);
+		break;
+
+	case ARG_OUTLINE_COLOR_GDK:
+		get_color_arg (mitem, mitem->outline_pixel, arg);
+		break;
+
+	case ARG_DAY_BOX_COLOR_GDK:
+		get_color_arg (mitem, mitem->day_box_pixel, arg);
+		break;
+
+	case ARG_DAY_COLOR_GDK:
+		get_color_arg (mitem, mitem->day_pixel, arg);
+		break;
+
 	default:
 		arg->type = GTK_TYPE_INVALID;
 		break;
 	}
 }
+
+GnomeCanvasItem *
+gnome_month_item_num2child (GnomeMonthItem *mitem, GnomeMonthItemChild child_num)
+{
+	g_return_val_if_fail (mitem != NULL, NULL);
+	g_return_val_if_fail (GNOME_IS_MONTH_ITEM (mitem), NULL);
+
+	return mitem->items[child_num];
+}
+
+GnomeMonthItemChild
+gnome_month_item_child2num (GnomeMonthItem *mitem, GnomeCanvasItem *child)
+{
+	int i;
+
+	g_return_val_if_fail (mitem != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_MONTH_ITEM (mitem), -1);
+	g_return_val_if_fail (child != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_CANVAS_ITEM (child), -1);
+
+	for (i = 0; i < GNOME_MONTH_ITEM_LAST; i++)
+		if (mitem->items[i] == child)
+			return i;
+
+	return -1;
+}
+
+int
+gnome_month_item_num2day (GnomeMonthItem *mitem, GnomeMonthItemChild child_num)
+{
+	g_return_val_if_fail (mitem != NULL, 0);
+	g_return_val_if_fail (GNOME_IS_MONTH_ITEM (mitem), 0);
+
+	if ((child_num >= GNOME_MONTH_ITEM_DAY_GROUP) && (child_num < GNOME_MONTH_ITEM_LAST)) {
+		child_num = (child_num - GNOME_MONTH_ITEM_DAY_GROUP) % 42;
+		return mitem->day_numbers[child_num];
+	} else
+		return 0;
+}
+
+int
+gnome_month_item_day2index (GnomeMonthItem *mitem, int day_num)
+{
+	int i;
+
+	g_return_val_if_fail (mitem != NULL, -1);
+	g_return_val_if_fail (GNOME_IS_MONTH_ITEM (mitem), -1);
+	g_return_val_if_fail (day_num >= 1, -1);
+
+	/* Find first day of month */
+
+	for (i = 0; mitem->day_numbers[i] == 0; i++)
+		;
+
+	/* Find the specified day */
+
+	for (; (mitem->day_numbers[i] != 0) && (i < 42); i++)
+		if (mitem->day_numbers[i] == day_num)
+			return i;
+
+	/* Bail out */
+
+	return -1;
+}
