@@ -4,6 +4,8 @@
 #include <time.h>
 #include <glib.h>
 
+#include "cardtypes.h"
+
 #define PO 0
 #define EXT 1
 #define STREET 2
@@ -20,26 +22,12 @@ typedef struct _group
 	struct _group *parent;
 } CardGroup;
 
-enum EncodType
-{
-	ENC_BASE64,
-	ENC_QUOTED_PRINTABLE,
-	ENC_8BIT,
-	ENC_7BIT
-};
-
-enum ValueType 
-{
-	VAL_INLINE,
-	VAL_CID,
-	VAL_URL
-};
-
 typedef struct
 {
 	CardGroup *grp;
-	
+
 	int used;
+	enum PropertyType type;
 	enum EncodType encod;
 	enum ValueType value;
 	char *charset;
@@ -70,13 +58,6 @@ typedef struct
 	char *suffix;        /* Esq. */
 } CardName;
 
-enum PhotoType
-{
-	PHOTO_GIF , PHOTO_CGM  , PHOTO_WMF , PHOTO_BMP, PHOTO_MET, PHOTO_PMB ,
-	PHOTO_DIB , PHOTO_PICT , PHOTO_TIFF, PHOTO_PS , PHOTO_PDF, PHOTO_JPEG,
-	PHOTO_MPEG, PHOTO_MPEG2, PHOTO_AVI , PHOTO_QTIME
-};
-
 typedef struct 
 {
 	CardProperty prop;
@@ -99,16 +80,6 @@ typedef struct
 /* DELIVERY ADDRESSING PROPERTIES */
 
 
-enum AddrType
-{
-	ADDR_DOM    = 1 << 0,
-	ADDR_INTL   = 1 << 1, 
-	ADDR_POSTAL = 1 << 2, 
-	ADDR_PARCEL = 1 << 3, 
-	ADDR_HOME   = 1 << 4, 
-	ADDR_WORK   = 1 << 5
-};
-
 typedef struct
 {
 	CardProperty prop;
@@ -129,23 +100,6 @@ typedef struct
 /* TELECOMMUNICATIONS ADDRESSING PROPERTIES */
 
 
-enum PhoneType
-{
-	PHONE_PREF  = 1 << 0,
-	PHONE_WORK  = 1 << 1,
-	PHONE_HOME  = 1 << 2,
-	PHONE_VOICE = 1 << 3,
-	PHONE_FAX   = 1 << 4,
-	PHONE_MSG   = 1 << 5,
-	PHONE_CELL  = 1 << 6,
-	PHONE_PAGER = 1 << 7,
-	PHONE_BBS   = 1 << 8,
-	PHONE_MODEM = 1 << 9,
-	PHONE_CAR   = 1 << 10,
-	PHONE_ISDN  = 1 << 11,
-	PHONE_VIDEO = 1 << 12 
-};
-
 typedef struct
 {
 	CardProperty prop;
@@ -154,22 +108,6 @@ typedef struct
 	char *data;
 } CardPhone;
 
-enum EMailType
-{
-	EMAIL_AOL,
-	EMAIL_APPLE_LINK,
-	EMAIL_ATT,
-	EMAIL_CIS,
-	EMAIL_EWORLD,
-	EMAIL_INET,
-	EMAIL_IBM,
-	EMAIL_MCI,
-	EMAIL_POWERSHARE,
-	EMAIL_PRODIGY,
-	EMAIL_TLX,
-	EMAIL_X400
-};
-
 typedef struct 
 {
 	CardProperty prop;
@@ -222,14 +160,6 @@ typedef struct
 	struct tm tm;
 } CardRev;
 
-enum SoundType
-{
-	SOUND_AIFF,
-	SOUND_PCM, 
-	SOUND_WAVE, 
-	SOUND_PHONETIC
-};
-
 typedef struct
 {
 	CardProperty prop;
@@ -239,12 +169,6 @@ typedef struct
 	char *data;
 } CardSound;
 
-enum KeyType
-{
-	KEY_X509, 
-	KEY_PGP
-};
-
 typedef struct
 {
 	CardProperty prop;
