@@ -36,6 +36,11 @@ typedef struct
 	GList *l;
 } GnomeCardEditor;
 
+typedef struct
+{
+	GtkWidget *def_phone, *def_email;
+} GnomeCardSetup;
+
 typedef struct
 {
 	GtkWidget *data, *type;
@@ -56,3 +61,15 @@ typedef struct
 	
 	GList *l;
 } GnomeCardDelAddr;
+
+typedef struct
+{
+	GtkWidget *type[6], *data;
+	
+	GList *l;
+} GnomeCardDelLabel;
+
+typedef struct
+{
+	GtkWidget *entry, *sens, *back;
+} GnomeCardFind;
