@@ -1,10 +1,10 @@
 /*
- * GnomeCalendar widget
+ * Main file for the GNOME Calendar program
  * Copyright (C) 1998 the Free Software Foundation
  *
  * Authors:
  *          Miguel de Icaza (miguel@kernel.org)
- *          Federico Mena (quartic@gimp.org)
+ *          Federico Mena (federico@nuclecu.unam.mx)
  */
 
 #include <config.h>
@@ -20,8 +20,10 @@
 #include "main.h"
 #include "timeutil.h"
 
+
 #define COOKIE_USER_HOME_DIR ((char *) -1)
 
+
 /* The username, used to set the `owner' field of the event */
 char *user_name;
 
@@ -37,7 +39,23 @@ char *calendar_settings;
 /* Day begin, day end parameters */
 int day_begin, day_end;
 
-/* Number of calendars active */
+/* Whether weeks starts on Sunday or Monday */
+int week_starts_on_monday;
+
+/* The array of color properties -- keep in sync with the enumeration defined in main.h.  The color
+ * values specified here are the defaults for the program.
+ */
+struct color_prop color_props[] = {
+	{ 0x0000, 0x0000, 0x0000, "Outline:",              "/calendar/Colors/outline" },
+	{ 0xffff, 0xffff, 0xffff, "Headings:",             "/calendar/Colors/headings" },
+	{ 0xd6d6, 0xd6d6, 0xd6d6, "Empty days:",           "/calendar/Colors/empty_bg" },
+	{ 0xd2d2, 0xb4b4, 0x8c8c, "Appointment days:",     "/calendar/Colors/mark_bg" },
+	{ 0xea60, 0xea60, 0xea60, "Highlighted day:",      "/calendar/Colors/prelight_bg" },
+	{ 0x0000, 0x0000, 0x0000, "Day numbers:",          "/calendar/Colors/day_fg" },
+	{ 0x0000, 0x0000, 0xffff, "Current day's number:", "/calendar/Colors/current_fg" }
+};
+
+/* Number of active calendars */
 int active_calendars = 0;
 
 /* A list of all of the calendars started */
@@ -100,19 +118,42 @@ range_check_hour (int hour)
 static void
 init_calendar (void)
 {
+	int i;
+	char *cspec, *color;
+	char *str;
+
 	init_username ();
 	user_calendar_file = g_concat_dir_and_file (gnome_util_user_home (), ".gnome/user-cal.vcf");
 
 	gnome_config_push_prefix (calendar_settings);
+
+	/* Read calendar settings */
+
 	day_begin  = range_check_hour (gnome_config_get_int  ("/calendar/Calendar/Day start=8"));
 	day_end    = range_check_hour (gnome_config_get_int  ("/calendar/Calendar/Day end=17"));
-	am_pm_flag = range_check_hour (gnome_config_get_bool ("/calendar/Calendar/AM PM flag=0"));
+	am_pm_flag = gnome_config_get_bool ("/calendar/Calendar/AM PM flag=0");
+	week_starts_on_monday = gnome_config_get_bool ("/calendar/Calendar/Week starts on Monday=0");
 
 	if (day_end < day_begin){
 		day_begin = 8;
 		day_end   = 17;
 	}
 
+	/* Read color settings */
+
+	for (i = 0; i < COLOR_PROP_LAST; i++) {
+		cspec = build_color_spec (color_props[i].r, color_props[i].g, color_props[i].b);
+		str = g_copy_strings (color_props[i].key, "=", cspec, NULL);
+
+		color = gnome_config_get_string (str);
+		parse_color_spec (color, &color_props[i].r, &color_props[i].g, &color_props[i].b);
+
+		g_free (str);
+		g_free (color);
+	}
+
+	/* Done */
+
 	gnome_config_pop_prefix ();
 }
 
@@ -124,7 +165,7 @@ about_calendar_cmd (GtkWidget *widget, void *data)
         GtkWidget *about;
         const gchar *authors[] = {
 		"Miguel de Icaza (miguel@kernel.org)",
-		"Federico Mena (quartic@gimp.org)",
+		"Federico Mena (federico@gimp.org)",
 		"Arturo Espinosa (arturo@nuclecu.unam.mx)",
 		NULL
 	};
@@ -134,6 +175,8 @@ about_calendar_cmd (GtkWidget *widget, void *data)
 				 authors,
 				 _("The GNOME personal calendar and schedule manager."),
 				 NULL);
+	gnome_dialog_set_modal (GNOME_DIALOG (about));
+	gnome_dialog_set_close (GNOME_DIALOG (about), TRUE);
         gtk_widget_show (about);
 }
 
@@ -180,19 +223,22 @@ close_cmd (GtkWidget *widget, GnomeCalendar *gcal)
 		gtk_main_quit ();
 }
 
-/*
- * Updates all of the open calendars when the day_begin/day_end values have changed
- */
 void
-day_range_changed (void)
+time_format_changed (void)
 {
 	GList *l;
 
-	for (l = all_calendars; l; l = l->next){
-		GnomeCalendar *cal = GNOME_CALENDAR (l->data);
+	for (l = all_calendars; l; l = l->next)
+		gnome_calendar_time_format_changed (GNOME_CALENDAR (l->data));
+}
 
-		gtk_widget_queue_resize (cal->notebook);
-	}
+void
+colors_changed (void)
+{
+	GList *l;
+
+	for (l = all_calendars; l; l = l->next)
+		gnome_calendar_colors_changed (GNOME_CALENDAR (l->data));
 }
 
 static void
@@ -205,22 +251,54 @@ quit_cmd (void)
 	}
 }
 
+/* Sets a clock cursor for the specified calendar window */
+static void
+set_clock_cursor (GnomeCalendar *gcal)
+{
+	GdkCursor *cursor;
+
+	cursor = gdk_cursor_new (GDK_WATCH);
+	gdk_window_set_cursor (GTK_WIDGET (gcal)->window, cursor);
+	gdk_cursor_destroy (cursor);
+	gdk_flush ();
+}
+
+/* Resets the normal cursor for the specified calendar window */
+static void
+set_normal_cursor (GnomeCalendar *gcal)
+{
+	gdk_window_set_cursor (GTK_WIDGET (gcal)->window, NULL);
+	gdk_flush ();
+}
+
 static void
 previous_clicked (GtkWidget *widget, GnomeCalendar *gcal)
 {
+	set_clock_cursor (gcal);
 	gnome_calendar_previous (gcal);
+	set_normal_cursor (gcal);
 }
 
 static void
 next_clicked (GtkWidget *widget, GnomeCalendar *gcal)
 {
+	set_clock_cursor (gcal);
 	gnome_calendar_next (gcal);
+	set_normal_cursor (gcal);
 }
 
 static void
 today_clicked (GtkWidget *widget, GnomeCalendar *gcal)
 {
-	gnome_calendar_goto (gcal, time (NULL));
+	set_clock_cursor (gcal);
+	gnome_calendar_goto_today (gcal);
+	set_normal_cursor (gcal);
+}
+
+static void
+goto_clicked (GtkWidget *widget, GnomeCalendar *gcal)
+{
+	goto_dialog (gcal);
 }
 
 static void
@@ -314,66 +392,67 @@ save_calendar_cmd (GtkWidget *widget, void *data)
 }
 
 static GnomeUIInfo gnome_cal_file_menu [] = {
-	{ GNOME_APP_UI_ITEM, N_("New calendar"),  NULL, new_calendar_cmd, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW },
+	{ GNOME_APP_UI_ITEM, N_("_New calendar"), NULL, new_calendar_cmd, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW, 'n', GDK_CONTROL_MASK, NULL },
+	{ GNOME_APP_UI_ITEM, N_("_Open calendar..."), NULL, open_calendar_cmd, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN, 'o', GDK_CONTROL_MASK, NULL },
+	{ GNOME_APP_UI_ITEM, N_("_Save calendar"), NULL, save_calendar_cmd, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE, 's', GDK_CONTROL_MASK, NULL },
+	{ GNOME_APP_UI_ITEM, N_("Save calendar _as..."), NULL, save_as_calendar_cmd, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE, 0, 0, NULL },
 
-	{ GNOME_APP_UI_ITEM, N_("Open calendar..."), NULL, open_calendar_cmd, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN },
-
-	{ GNOME_APP_UI_ITEM, N_("Save calendar"), NULL, save_calendar_cmd, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE },
-
-	{ GNOME_APP_UI_ITEM, N_("Save calendar as..."), NULL, save_as_calendar_cmd, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SAVE },
-
-	{ GNOME_APP_UI_SEPARATOR },
-	{ GNOME_APP_UI_ITEM, N_("Close this calendar"), NULL, close_cmd, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT },
-
-	{ GNOME_APP_UI_ITEM, N_("Exit"), NULL, quit_cmd, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT },
-
-	GNOMEUIINFO_END
-};
-
-static GnomeUIInfo gnome_cal_about_menu [] = {
-	{ GNOME_APP_UI_ITEM, N_("About..."), NULL, about_calendar_cmd, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT },
 	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_HELP ("cal"),
+
+	{ GNOME_APP_UI_ITEM, N_("P_references..."), NULL, properties, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PREF, 0, 0, NULL },
+
+	GNOMEUIINFO_SEPARATOR,
+
+	{ GNOME_APP_UI_ITEM, N_("_Close this calendar"), NULL, close_cmd, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'w', GDK_CONTROL_MASK, NULL },
+	{ GNOME_APP_UI_ITEM, N_("E_xit"), NULL, quit_cmd, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'x', GDK_CONTROL_MASK, NULL },
+
 	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo gnome_cal_edit_menu [] = {
-	{ GNOME_APP_UI_ITEM, N_("New appointment..."), NULL, display_objedit },
-	{ GNOME_APP_UI_ITEM, N_("New appointment for today..."), NULL, display_objedit_today },
+	{ GNOME_APP_UI_ITEM, N_("_New appointment..."), NULL, display_objedit, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, N_("New appointment for _today..."), NULL, display_objedit_today, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW, 0, 0, NULL },
+	GNOMEUIINFO_END
+};
+
+static GnomeUIInfo gnome_cal_help_menu [] = {
+	{ GNOME_APP_UI_ITEM, N_("_About Gnomecal..."), NULL, about_calendar_cmd, NULL, NULL,
+	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, 0, 0, NULL },
+
 	GNOMEUIINFO_SEPARATOR,
-	{ GNOME_APP_UI_ITEM, N_("Properties..."),      NULL, properties, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PROP },
+
+	GNOMEUIINFO_HELP ("cal"),
 	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo gnome_cal_menu [] = {
-	{ GNOME_APP_UI_SUBTREE, N_("File"), NULL, &gnome_cal_file_menu },
-	{ GNOME_APP_UI_SUBTREE, N_("Calendar"), NULL, &gnome_cal_edit_menu },
-	{ GNOME_APP_UI_SUBTREE, N_("Help"), NULL, &gnome_cal_about_menu },
+	GNOMEUIINFO_SUBTREE (N_("_File"), &gnome_cal_file_menu),
+	GNOMEUIINFO_SUBTREE (N_("_Edit"), &gnome_cal_edit_menu),
+	GNOMEUIINFO_SUBTREE (N_("_Help"), &gnome_cal_help_menu),
 	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo gnome_toolbar [] = {
-	{ GNOME_APP_UI_ITEM, N_("New"), N_("Create a new appointment"), display_objedit, 0, 0,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_NEW },
+	GNOMEUIINFO_ITEM_STOCK (N_("New"), N_("Create a new appointment"), display_objedit, GNOME_STOCK_PIXMAP_NEW),
 
 	GNOMEUIINFO_SEPARATOR,
 
-	{ GNOME_APP_UI_ITEM, N_("Prev"), N_("Go back in time"), previous_clicked, 0, 0,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BACK },
+	GNOMEUIINFO_ITEM_STOCK (N_("Prev"), N_("Go back in time"), previous_clicked, GNOME_STOCK_PIXMAP_BACK),
+	GNOMEUIINFO_ITEM_STOCK (N_("Today"), N_("Go to present time"), today_clicked, GNOME_STOCK_PIXMAP_HOME),
+	GNOMEUIINFO_ITEM_STOCK (N_("Next"), N_("Go forward in time"), next_clicked, GNOME_STOCK_PIXMAP_FORWARD),
 
-	{ GNOME_APP_UI_ITEM, N_("Today"), N_("Go to present time"), today_clicked, 0, 0,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_PIXMAP_HOME },
+	GNOMEUIINFO_SEPARATOR,
 
-	{ GNOME_APP_UI_ITEM, N_("Next"), N_("Go forward in time"), next_clicked, 0, 0,
-	  GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_FORWARD },
+	GNOMEUIINFO_ITEM_STOCK (N_("Go to"), N_("Go to a specific date"), goto_clicked, GNOME_STOCK_PIXMAP_JUMP_TO),
 
 	GNOMEUIINFO_END
 };
