@@ -19,13 +19,8 @@
 #define __DIALOG_H__
 
 
-/*
- * The dialog created is a window widget - not a dialog widget!
- */
-
 gint gtt_delete_event(GtkWidget *w, gpointer *data);
 
-void new_dialog(char *title, GtkWidget **dlg, GtkBox **vbox_return, GtkBox **aa_return);
 void new_dialog_ok(char *title, GtkWidget **dlg, GtkBox **vbox,
 		       char *s, GtkSignalFunc sigfunc, gpointer *data);
 void new_dialog_ok_cancel(char *title, GtkWidget **dlg, GtkBox **vbox,
