@@ -24,11 +24,6 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-#undef gettext
-#undef _
-#include <libintl.h>
-#define _(String) gettext(String)
-
 
 static int log_write(time_t t, char *s)
 {
@@ -47,6 +42,79 @@ static int log_write(time_t t, char *s)
 }
 
 
+static char *
+build_log_entry(char *format, project *proj)
+{
+	GString *str;
+	char tmp[256];
+	char *p;
+
+	if (!format)
+		format = config_logfile_str;
+	if (!proj)
+		return g_strdup(_("program started"));
+	if ((!format) || (!format[0]))
+		return g_strdup(proj->title);
+	str = g_string_new(NULL);
+	for (p = format; *p; p++) {
+		if (*p != '%') {
+			g_string_append_c(str, *p);
+		} else {
+			p++;
+			switch (*p) {
+			case 't':
+				g_string_append(str, proj->title);
+				break;
+			case 'd':
+				if (proj->desc)
+					g_string_append(str, proj->desc);
+				else
+					g_string_append(str,
+							_("no description"));
+				break;
+			case 'T':
+				sprintf(tmp, "%d:%02d:%02d", proj->secs / 3600,
+					(proj->secs / 60) % 60,
+					proj->secs % 60);
+				g_string_append(str, tmp);
+				break;
+			case 'm':
+				sprintf(tmp, "%d", proj->day_secs / 60);
+				g_string_append(str, tmp);
+				break;
+			case 'M':
+				sprintf(tmp, "%02d",
+					(proj->day_secs / 60) % 60);
+				g_string_append(str, tmp);
+				break;
+			case 's':
+				sprintf(tmp, "%d", proj->day_secs);
+				g_string_append(str, tmp);
+				break;
+			case 'S':
+				sprintf(tmp, "%02d", proj->day_secs % 60);
+				g_string_append(str, tmp);
+				break;
+			case 'h':
+				sprintf(tmp, "%d", proj->day_secs / 3600);
+				g_string_append(str, tmp);
+				break;
+			case 'H':
+				sprintf(tmp, "%02d", proj->day_secs / 3600);
+				g_string_append(str, tmp);
+				break;
+			default:
+				g_string_append_c(str, *p);
+				break;
+			}
+		}
+	}
+	p = str->str;
+	g_string_free(str, 0);
+	return p;
+}
+
+
 
 static char *last_msg = NULL;
 static char *last_logged_msg = NULL;
@@ -55,12 +123,16 @@ static time_t last_time = -1;
 static void log_last(time_t t, project *proj)
 {
 	char *s;
+	static project *last_proj = NULL;
 
 	if (last_msg) {
 		s = last_msg;
 	} else {
-		s = g_strdup(_("stopped project"));
+		/* s = g_strdup(_("stopped project")); */
+		s = build_log_entry(config_logfile_stop, last_proj);
 	}
+	if (proj)
+		last_proj = proj;
 	if ((!last_logged_msg) || (0 != strcmp(s, last_logged_msg))) {
 		if (!log_write(last_time, s)) {
 			g_warning("couldn't write to logfile `%s'.\n",
@@ -69,7 +141,7 @@ static void log_last(time_t t, project *proj)
 	}
 	if (last_logged_msg) g_free(last_logged_msg);
 	last_logged_msg = s;
-	if (proj) last_msg = g_strdup(proj->title);
+	if (proj) last_msg = build_log_entry(NULL, proj);
 	else last_msg = NULL;
 	last_time = t;
 }
@@ -77,6 +149,7 @@ static void log_last(time_t t, project *proj)
 static void log_proj_intern(project *proj, int log_if_equal)
 {
 	time_t t;
+	char *new_msg;
 
 	if ((log_if_equal) && (last_logged_msg)) {
 		g_free(last_logged_msg);
@@ -93,15 +166,17 @@ static void log_proj_intern(project *proj, int log_if_equal)
 	t = time(NULL);
 	if ((last_time != -1) &&
 	    ((long int)(t - last_time) < config_logfile_min_secs)) {
+		new_msg = build_log_entry(NULL, proj);
 		if (proj == NULL) {
 			if (last_msg) last_time = t;
 		} else {
 			if ((!last_msg) ||
-			    (0 != strcmp(last_msg, proj->title)))
+			    (0 != strcmp(last_msg, new_msg)))
 				last_time = t;
 		}
 		if (last_msg) g_free(last_msg);
-		last_msg = (proj) ? g_strdup(proj->title) : NULL;
+		last_msg = (proj) ? g_strdup(new_msg) : NULL;
+		g_free(new_msg);
 		return;
 	}
 	log_last(t, proj);
@@ -118,14 +193,9 @@ void log_proj(project *proj)
 
 void log_exit(void)
 {
-	static int was_run = 0;
-	
 	if ((!config_logfile_name) || (!config_logfile_use))
 		return;
-	/* TODO: make shure this isn't run twice at exit */
-	g_return_if_fail(was_run == 0);
-	was_run++;
-	log_last(-1, NULL);
+	log_proj_intern(NULL, 0);
 	log_write(-1, _("program exited"));
 }
 
