@@ -23,12 +23,6 @@
 #include "gtt.h"
 
 
-#undef gettext
-#undef _
-#include <libintl.h>
-#define _(String) gettext(String)
-
-
 typedef struct _OptionsDlg {
 	GnomePropertyBox *dlg;
 	GtkCheckButton *show_secs;
@@ -47,6 +41,10 @@ typedef struct _OptionsDlg {
 	GtkCheckButton *logfileuse;
 	GtkEntry *logfileminsecs;
 	GtkWidget *logfileminsecs_l;
+	GtkWidget *logfilestr_l;
+	GnomeEntry *logfilestr;
+	GtkWidget *logfilestop_l;
+	GnomeEntry *logfilestop;
 } OptionsDlg;
 
 
@@ -88,6 +86,10 @@ static void options_apply_cb(GnomePropertyBox *pb, gint page, OptionsDlg *odlg)
 	config_logfile_use = GTK_TOGGLE_BUTTON(odlg->logfileuse)->active;
 	ENTRY_TO_CHAR(GTK_ENTRY(gnome_file_entry_gtk_entry(odlg->logfilename)),
 		      config_logfile_name);
+	ENTRY_TO_CHAR(GTK_ENTRY(gnome_entry_gtk_entry(odlg->logfilestr)),
+		      config_logfile_str);
+	ENTRY_TO_CHAR(GTK_ENTRY(gnome_entry_gtk_entry(odlg->logfilestop)),
+		      config_logfile_stop);
 	config_logfile_min_secs = atoi(gtk_entry_get_text(odlg->logfileminsecs));
 
         /* toolbar */
@@ -354,6 +356,10 @@ static void logfile_sigfunc(GtkWidget *w, OptionsDlg *odlg)
 	state = GTK_TOGGLE_BUTTON(odlg->logfileuse)->active;
 	gtk_widget_set_sensitive(GTK_WIDGET(odlg->logfilename), state);
 	gtk_widget_set_sensitive(odlg->logfilename_l, state);
+	gtk_widget_set_sensitive(GTK_WIDGET(odlg->logfilestr), state);
+	gtk_widget_set_sensitive(odlg->logfilestr_l, state);
+	gtk_widget_set_sensitive(GTK_WIDGET(odlg->logfilestop), state);
+	gtk_widget_set_sensitive(odlg->logfilestop_l, state);
 	gtk_widget_set_sensitive(GTK_WIDGET(odlg->logfileminsecs), state);
 	gtk_widget_set_sensitive(odlg->logfileminsecs_l, state);
 }
@@ -361,53 +367,76 @@ static void logfile_sigfunc(GtkWidget *w, OptionsDlg *odlg)
 static void logfile_options(OptionsDlg *odlg, GtkBox *vbox)
 {
 	GtkWidget *w, *frame;
-	GtkBox *vbox2, *hbox;
+	GtkTable *table;
 
 	frame = gtk_frame_new(_("Logfile"));
 	gtk_widget_show(frame);
 	gtk_box_pack_start(vbox, frame, FALSE, FALSE, 2);
-	
-	vbox2 = GTK_BOX(gtk_vbox_new(FALSE, 2));
-	gtk_widget_show(GTK_WIDGET(vbox2));
-	gtk_container_add(GTK_CONTAINER(frame), GTK_WIDGET(vbox2));
 
+	table = GTK_TABLE(gtk_table_new(4, 2, FALSE));
+	gtk_widget_show(GTK_WIDGET(table));
+	gtk_container_add(GTK_CONTAINER(frame), GTK_WIDGET(table));
+	
 	w = gtk_check_button_new_with_label(_("Use Logfile"));
 	gtk_widget_show(w);
-	gtk_box_pack_start(vbox2, w, FALSE, FALSE, 0);
+	gtk_table_attach_defaults(table, w, 0, 3, 0, 1);
 	gtk_signal_connect(GTK_OBJECT(w), "clicked",
 			   GTK_SIGNAL_FUNC(logfile_sigfunc),
 			   (gpointer *)odlg);
 	odlg->logfileuse = GTK_CHECK_BUTTON(w);
 	toggle_changes_property_box(odlg, w);
 
-	hbox = GTK_BOX(gtk_hbox_new(FALSE, 5));
-	gtk_widget_show(GTK_WIDGET(hbox));
-	gtk_box_pack_start(vbox2, GTK_WIDGET(hbox), FALSE, FALSE, 0);
-
 	w = gtk_label_new(_("Filename:"));
 	gtk_misc_set_alignment(GTK_MISC(w), 1.0, 0.5);
 	gtk_widget_show(w);
-	gtk_box_pack_start(hbox, w, FALSE, FALSE, 0);
+	gtk_table_attach(table, w, 0, 1, 1, 2,
+			 GTK_FILL, GTK_EXPAND, 0, 0);
 	odlg->logfilename_l = w;
 	w = gnome_file_entry_new("logfilename", "Logfile");
 	gtk_widget_show(w);
-	gtk_box_pack_end(hbox, w, FALSE, FALSE, 0);
+	gtk_table_attach(table, w, 1, 3, 1, 2, GTK_EXPAND | GTK_FILL,
+			 GTK_EXPAND, 3, 0);
 	odlg->logfilename = GNOME_FILE_ENTRY(w);
 	entry_changes_property_box(odlg, 
 				   gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(w)));
 
-	hbox = GTK_BOX(gtk_hbox_new(FALSE, 5));
-	gtk_widget_show(GTK_WIDGET(hbox));
-	gtk_box_pack_start(vbox2, GTK_WIDGET(hbox), FALSE, FALSE, 0);
+	w = gtk_label_new(_("Entry Start:"));
+	gtk_misc_set_alignment(GTK_MISC(w), 1.0, 0.5);
+	gtk_widget_show(w);
+	gtk_table_attach(table, w, 0, 1, 2, 3,
+			 GTK_FILL, GTK_EXPAND, 0, 0);
+	odlg->logfilestr_l = w;
+	w = gnome_entry_new("logfilestr");
+	gtk_widget_show(w);
+	gtk_table_attach(table, w, 1, 3, 2, 3,
+			 GTK_EXPAND | GTK_FILL, GTK_EXPAND, 3, 0);
+	odlg->logfilestr = GNOME_ENTRY(w);
+	entry_changes_property_box(odlg,
+				   gnome_entry_gtk_entry(GNOME_ENTRY(w)));
+
+	w = gtk_label_new(_("Entry Stop:"));
+	gtk_misc_set_alignment(GTK_MISC(w), 1.0, 0.5);
+	gtk_widget_show(w);
+	gtk_table_attach(table, w, 0, 1, 3, 4,
+			 GTK_FILL, GTK_EXPAND, 0, 0);
+	odlg->logfilestop_l = w;
+	w = gnome_entry_new("logfilestop");
+	gtk_widget_show(w);
+	gtk_table_attach(table, w, 1, 3, 3, 4,
+			 GTK_EXPAND | GTK_FILL, GTK_EXPAND, 3, 0);
+	odlg->logfilestop = GNOME_ENTRY(w);
+	entry_changes_property_box(odlg,
+				   gnome_entry_gtk_entry(GNOME_ENTRY(w)));
 
 	w = gtk_label_new(_("Timeout in secs:"));
 	gtk_misc_set_alignment(GTK_MISC(w), 1.0, 0.5);
 	gtk_widget_show(w);
-	gtk_box_pack_start(hbox, w, FALSE, FALSE, 0);
+	gtk_table_attach(table, w, 0, 1, 4, 5, GTK_FILL,
+			 GTK_EXPAND, 0, 0);
 	odlg->logfileminsecs_l = w;
 	w = gtk_entry_new();
 	gtk_widget_show(w);
-	gtk_box_pack_end(hbox, w, FALSE, FALSE, 0);
+	gtk_table_attach(table, w, 1, 2, 4, 5, GTK_FILL, GTK_EXPAND, 3, 0);
 	odlg->logfileminsecs = GTK_ENTRY(w);
 	entry_changes_property_box(odlg, w);
 }
@@ -433,6 +462,8 @@ static void options_dialog_set(OptionsDlg *odlg)
 	if (config_command_null) gtk_entry_set_text(odlg->command_null, config_command_null);
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(odlg->logfileuse), config_logfile_use);
 	if (config_logfile_name) gtk_entry_set_text(GTK_ENTRY(gnome_file_entry_gtk_entry(odlg->logfilename)), config_logfile_name);
+	if (config_logfile_str) gtk_entry_set_text(GTK_ENTRY(gnome_entry_gtk_entry(odlg->logfilestr)), config_logfile_str);
+	if (config_logfile_stop) gtk_entry_set_text(GTK_ENTRY(gnome_entry_gtk_entry(odlg->logfilestop)), config_logfile_stop);
 	sprintf(s, "%d", config_logfile_min_secs);
 	gtk_entry_set_text(odlg->logfileminsecs, s);
 
