@@ -35,7 +35,7 @@ struct _MyToolbar {
         GtkWidget *cut, *copy, *paste; /* to make them sensible
                                           as needed */
         GtkWidget *prop_w;
-	GnomeStockPixmapWidget *timer;
+	GnomeStock *timer;
 };
 
 MyToolbar *mytbar = NULL;
@@ -55,7 +55,7 @@ add_stock_button(GtkToolbar *tbar, char *text, char *tt_text,
 }
 
 
-static GnomeStockPixmapWidget *
+static GnomeStock *
 add_toggle_button(GtkToolbar *tbar, char *text, char *tt_text,
                  char *icon, GtkSignalFunc sigfunc)
 {
@@ -64,7 +64,7 @@ add_toggle_button(GtkToolbar *tbar, char *text, char *tt_text,
 	w = gnome_stock_pixmap_widget((GtkWidget *)window, icon);
 	gtk_toolbar_append_item(tbar, text, tt_text, NULL, w,
 				sigfunc, NULL);
-	return GNOME_STOCK_PIXMAP_WIDGET(w);
+	return GNOME_STOCK(w);
 }
 
 
@@ -95,10 +95,10 @@ toolbar_set_states(void)
         if (mytbar->prop_w)
                 gtk_widget_set_sensitive(mytbar->prop_w, (cur_proj != NULL));
         if (mytbar->timer)
-		gnome_stock_pixmap_widget_set_icon(mytbar->timer,
-						   (main_timer != 0) ?
-						   GNOME_STOCK_PIXMAP_TIMER :
-						   GNOME_STOCK_PIXMAP_TIMER_STOP);
+		gnome_stock_set_icon(mytbar->timer,
+				     (main_timer != 0) ?
+				     GNOME_STOCK_PIXMAP_TIMER :
+				     GNOME_STOCK_PIXMAP_TIMER_STOP);
 
 	if ((config_show_tb_icons) && (config_show_tb_texts)) {
 		tb_style = GTK_TOOLBAR_BOTH;
