@@ -3,9 +3,13 @@
 "Elliot Lee",
 "Federico Mena",
 "George Lebl",
+"Havoc Pennington",
 "Jaka Mocnik",
 "Jens Christian Restemeier",
+"Jonathan Blanford",
+"Marc Ewing",
 "Marius Vollmer",
+"Michael Fulbright",
 "Michael K. Johnson",
 "Miguel de Icaza",
 "Molaro Paolo",
@@ -14,6 +18,7 @@
 "Seth Alves",
 "Shawn Amundson",
 "Szekeres Istvan",
+"The Rasterman",
 "Tim Janik",
 "Tom Tromey",
 "Tuomas Kuosmanen",
